@@ -84,6 +84,7 @@ struct _SwServiceClass {
 #define HAS_VIDEO_UPLOAD_IFACE "has-video-upload-iface"
 #define HAS_BANISHABLE_IFACE "has-banishable-iface"
 #define HAS_QUERY_IFACE "has-query-iface"
+#define HAS_COLLECTIONS_IFACE "has-collections-iface"
 
 #define CAN_UPDATE_STATUS_WITH_GEOTAG "can-update-status-with-geotag"
 
@@ -99,6 +100,33 @@ gboolean sw_service_is_uid_banned (SwService   *service,
                                    const gchar *uid);
 
 gboolean sw_service_has_cap (const char **caps, const char *cap);
+
+typedef struct {
+  char *lsw_param;
+  char *service_param;
+} ParameterNameMapping;
+
+/**
+ * SwServiceSetParamFunc:
+ * @object: A remote call or hash object that can store key/value pairs.
+ * @param_name: The parameter name.
+ * @param_value: The parameter value.
+ *
+ * This type signature reflects a function that sets a name/value association
+ * on a given object. Functions such as g_hash_table_insert and
+ * rest_proxy_call_add_param are good examples.
+ */
+
+
+typedef void (*SwServiceSetParamFunc) (gpointer object,
+                                       const gchar *param_name,
+                                       const gchar *param_value);
+
+void sw_service_map_params (const ParameterNameMapping *mapping,
+                            GHashTable                 *parameters,
+                            SwServiceSetParamFunc       set_param_func,
+                            gpointer                    remote_call_object);
+
 G_END_DECLS
 
 #endif /* _SW_SERVICE */
